about summary refs log tree commit diff
path: root/pkgs/applications/misc/gpsbabel
diff options
context:
space:
mode:
authorDaiderd Jordan <daiderd@gmail.com>2017-04-11 20:18:53 +0200
committerDaiderd Jordan <daiderd@gmail.com>2017-04-11 20:23:43 +0200
commit9561fecd02a547e2a47afdc9afc51af72f2e3eff (patch)
treede1d2282c1f0eee90d0a6bdfe9a1b5f1bcca1512 /pkgs/applications/misc/gpsbabel
parent08656a73f06e27c2a73ccdfcaa434f8ee26da2fb (diff)
downloadnixlib-9561fecd02a547e2a47afdc9afc51af72f2e3eff.tar
nixlib-9561fecd02a547e2a47afdc9afc51af72f2e3eff.tar.gz
nixlib-9561fecd02a547e2a47afdc9afc51af72f2e3eff.tar.bz2
nixlib-9561fecd02a547e2a47afdc9afc51af72f2e3eff.tar.lz
nixlib-9561fecd02a547e2a47afdc9afc51af72f2e3eff.tar.xz
nixlib-9561fecd02a547e2a47afdc9afc51af72f2e3eff.tar.zst
nixlib-9561fecd02a547e2a47afdc9afc51af72f2e3eff.zip
gpsbabel: fix build with llvm-4
Diffstat (limited to 'pkgs/applications/misc/gpsbabel')
-rw-r--r--pkgs/applications/misc/gpsbabel/clang-4.patch22
-rw-r--r--pkgs/applications/misc/gpsbabel/default.nix5
2 files changed, 25 insertions, 2 deletions
diff --git a/pkgs/applications/misc/gpsbabel/clang-4.patch b/pkgs/applications/misc/gpsbabel/clang-4.patch
new file mode 100644
index 000000000000..6bd19ae60440
--- /dev/null
+++ b/pkgs/applications/misc/gpsbabel/clang-4.patch
@@ -0,0 +1,22 @@
+diff --git a/bushnell.cc b/bushnell.cc
+index 8fa844d..40707c4 100644
+--- a/bushnell.cc
++++ b/bushnell.cc
+@@ -135,7 +135,7 @@ bushnell_get_icon_from_name(QString name)
+     name = "Waypoint";
+   }
+
+-  for (t = bushnell_icons; t->icon > 0; t++) {
++  for (t = bushnell_icons; t->icon != 0; t++) {
+     if (0 == name.compare(t->icon, Qt::CaseInsensitive)) {
+       return t->symbol;
+     }
+@@ -147,7 +147,7 @@ static const char*
+ bushnell_get_name_from_symbol(signed int s)
+ {
+   icon_mapping_t* t;
+-  for (t = bushnell_icons; t->icon > 0; t++) {
++  for (t = bushnell_icons; t->icon != 0; t++) {
+     if (s == t->symbol) {
+       return t->icon;
+     }
diff --git a/pkgs/applications/misc/gpsbabel/default.nix b/pkgs/applications/misc/gpsbabel/default.nix
index d017c704484f..ace89cd8a21b 100644
--- a/pkgs/applications/misc/gpsbabel/default.nix
+++ b/pkgs/applications/misc/gpsbabel/default.nix
@@ -12,6 +12,7 @@ stdenv.mkDerivation rec {
   };
 
   patches = [
+    ./clang-4.patch
     (fetchpatch {
       url = https://sources.debian.net/data/main/g/gpsbabel/1.5.3-2/debian/patches/use_minizip;
       sha256 = "03fpsmlx1wc48d1j405zkzp8j64hcp0z72islf4mk1immql3ibcr";
@@ -44,8 +45,8 @@ stdenv.mkDerivation rec {
   ''
     # The raymarine and gtm tests fail on i686 despite -ffloat-store.
   + lib.optionalString stdenv.isi686 "rm -v testo.d/raymarine.test testo.d/gtm.test;"
-    # The tomtom asc test fails on darwin, see PR #23572.
-  + lib.optionalString stdenv.isDarwin "rm -v testo.d/tomtom_asc.test;";
+    # The gtm, kml and tomtom asc tests fail on darwin, see PR #23572.
+  + lib.optionalString stdenv.isDarwin "rm -v testo.d/gtm.test testo.d/kml.test testo.d/tomtom_asc.test";
 
   meta = with stdenv.lib; {
     description = "Convert, upload and download data from GPS and Map programs";